@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import importlib
+import logging
 import multiprocessing
 import os
 import platform
@@ -35,7 +36,6 @@ from trainer.io import (
     save_best_model,
     save_checkpoint,
 )
-from trainer.logger import logger
 from trainer.logging import ConsoleLogger, DummyLogger, logger_factory
 from trainer.trainer_utils import (
     get_optimizer,
@@ -45,9 +45,10 @@ from trainer.trainer_utils import (
 )
 from trainer.utils.distributed import init_distributed
 
-multiprocessing.set_start_method("fork")
+logger = logging.getLogger("trainer")
 
 if platform.system() != "Windows":
+    multiprocessing.set_start_method("fork")
     # https://github.com/pytorch/pytorch/issues/973
     import resource
 
@@ -184,9 +185,9 @@ class TrainerConfig(Coqpit):
     )
     cudnn_enable: bool = field(default=True, metadata={"help": "Enable/disable cudnn explicitly. Defaults to True"})
     cudnn_deterministic: bool = field(
-        default=True,
+        default=False,
         metadata={
-            "help": "Enable/disable deterministic cudnn operations. Set this True for better reproducibility. Defaults to True."
+            "help": "Enable/disable deterministic cudnn operations. Set this True for reproducibility but it slows down training significantly.  Defaults to False."
         },
     )
     cudnn_benchmark: bool = field(
@@ -242,6 +243,10 @@ class TrainerArgs(Coqpit):
         default=False,
         metadata={"help": "Skip training and only run evaluation and test."},
     )
+    small_run: int = field(
+        default=None,
+        metadata={"help": "Only use a subset of the samples for debugging. Set the number of samples to use."},
+    )
     gpu: int = field(
         default=None, metadata={"help": "GPU ID to use if ```CUDA_VISIBLE_DEVICES``` is not set. Defaults to None."}
     )
@@ -400,7 +405,7 @@ class Trainer:
         self.dashboard_logger, self.c_logger = self.init_loggers(
             self.args, self.config, output_path, dashboard_logger, c_logger
         )
-        self.c_logger.logger = logger
+        # self.c_logger.logger = logger
 
         if not self.config.log_model_step:
             self.config.log_model_step = self.config.save_step
@@ -438,6 +443,13 @@ class Trainer:
             self.eval_samples = None
             self.test_samples = None
 
+        # only use a subset of the samples if small_run is set
+        if args.small_run is not None:
+            print(f"[!] Small Run, only using {args.small_run} samples.")
+            self.train_samples = None if self.train_samples is None else self.train_samples[: args.small_run]
+            self.eval_samples = None if self.eval_samples is None else self.eval_samples[: args.small_run]
+            self.test_samples = None if self.test_samples is None else self.test_samples[: args.small_run]
+
         # init the model
         if model is None and get_model is None:
             raise ValueError("[!] `model` and `get_model` cannot both be None.")
@@ -1667,20 +1679,16 @@ class Trainer:
 
     def _setup_logger_config(self, log_file: str) -> None:
         """Set up the logger based on the process rank in DDP."""
-        global logger  # pylint: disable=global-statement
-        import logging  # pylint: disable=import-outside-toplevel
 
-        handler = logging.FileHandler(log_file)
-        logger.addHandler(handler)
+        logger_new = logging.getLogger("trainer")
+        handler = logging.FileHandler(log_file, mode="a")
+        fmt = logging.Formatter("")
+        handler.setFormatter(fmt)
+        logger_new.addHandler(handler)
 
-        # only log to a file if rank > 0
+        # only log to a file if rank > 0 in DDP
         if self.args.rank > 0:
-            handler = logging.FileHandler(log_file)
-            handler.setFormatter(logging.Formatter(""))
-            new_logger = logging.getLogger("trainer_ddp")
-            new_logger.addHandler(handler)
-            new_logger.setLevel(logging.INFO)
-            logger = new_logger
+            logger_new.handlers = [h for h in logger_new.handlers if not isinstance(h, logging.StreamHandler)]
 
     @staticmethod
     def _is_apex_available() -> bool:
